Index: chrome/browser/ui/gtk/collected_cookies_gtk.h |
diff --git a/chrome/browser/ui/gtk/collected_cookies_gtk.h b/chrome/browser/ui/gtk/collected_cookies_gtk.h |
index 8c6851b4ca20ac875994a322972957251745020d..1efca079d1e4cc52f96db5428331cdf9247d9926 100644 |
--- a/chrome/browser/ui/gtk/collected_cookies_gtk.h |
+++ b/chrome/browser/ui/gtk/collected_cookies_gtk.h |
@@ -44,11 +44,11 @@ class CollectedCookiesGtk : public ConstrainedWindowGtkDelegate, |
// Initialize all widgets of this dialog. |
void Init(); |
- // True if the selection contains at least one origin node. |
- bool SelectionContainsOriginNode(GtkTreeSelection* selection, |
- gtk_tree::TreeAdapter* adapter); |
+ // True if the selection contains at least one host node. |
+ bool SelectionContainsHostNode(GtkTreeSelection* selection, |
+ gtk_tree::TreeAdapter* adapter); |
- // Enable the allow/block buttons if at least one origin node is selected. |
+ // Enable the allow/block buttons if at least one host node is selected. |
void EnableControls(); |
// Add exceptions for all origin nodes within the selection. |